# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2018-06-19 14:23
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ping_me', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='domain',
            name='id',
            field=models.AutoField(auto_created=True, default=1, primary_key=True, serialize=False, verbose_name='ID'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='domain',
            name='url',
            field=models.CharField(max_length=255, verbose_name='Adresse'),
        ),
    ]
