# Generated by Django 2.0.6 on 2018-06-20 01:06

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ping_me', '0005_auto_20180620_0000'),
    ]

    operations = [
        migrations.CreateModel(
            name='PingSummary',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date', models.DateField()),
                ('nb_success', models.IntegerField(default=0)),
                ('nb_errors', models.IntegerField(default=0)),
                ('domain', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='ping_me.Domain')),
            ],
        ),
    ]
