# Generated by Django 2.0.6 on 2018-06-19 23:56

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ping_me', '0003_auto_20180619_1711'),
    ]

    operations = [
        migrations.CreateModel(
            name='Ping',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date', models.DateTimeField()),
                ('success', models.BooleanField()),
                ('address', models.GenericIPAddressField()),
                ('domain', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='ping_me.Domain')),
            ],
        ),
    ]
