# Generated by Django 2.0.6 on 2018-06-20 00:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ping_me', '0004_ping'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ping',
            name='date',
            field=models.DateTimeField(auto_now_add=True),
        ),
    ]
