# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2018-06-19 17:11
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ping_me', '0002_auto_20180619_1423'),
    ]

    operations = [
        migrations.AlterField(
            model_name='domain',
            name='description',
            field=models.CharField(max_length=255, verbose_name='Description'),
        ),
    ]
