# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2018-06-19 13:08
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Domain',
            fields=[
                ('url', models.CharField(max_length=255, primary_key=True, serialize=False, verbose_name='Adresse')),
                ('description', models.TextField(verbose_name='Description')),
            ],
        ),
    ]
